==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/tl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Pamahalaan Lightbox Gallary Parameter");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "pamahalaan ang Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Sukat ng Imahe Lapad");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Sukat ng Imahe Taas");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Laki nang Imahen");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Taas");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Panatilihin Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "show Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Huwag paganahin ang Suriin");
define('MANAGE_GALLERY_DELETE_IMAGE', "Burahin Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "I-save ang uri-uriin ang pagkasunod-sunod");
define('MANAGE_GALLERY_PUBLISH_MSG', "I-click ang &#39;I-update&#39; na mag-publish <br /> iyong na-upload na mga imahe.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Lahat ng mga larawan ay nai-laki at mga setting ay nai-save.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Nagkaroon ng error sa pagbabago ng laki ng mga imahe o pag-save setting.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ang iyong imahe (s) ay nai-upload.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Nagkaroon ng error sa pag-upload ang iyong mga imahe (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Ang file na sinusubukan mong i-upload ay hindi isang imahe.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Ang file na sinusubukan mong i-upload ay masyadong malaki.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Ang pamagat ay nai-save.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Sigurado ka bang gusto mong tanggalin ang imahe");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Ang imahe ay tinanggal na.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Nagkaroon ng error sa pagbubura ng mga imahe.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Sine-save ang mga parameter at ang pagbabago ng laki ng mga imahe, mangyaring maghintay ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Ina-upload, mangyaring maghintay ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Ang sort order ay hindi pa nai-save. Gusto mo bang i-save ang sort order?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Ang imahe sort order ay nai-save.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Nagkaroon ng error sa pag-save ang imahe sort.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/tl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Pamahalaan Lightbox Gallary Parameter");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "pamahalaan ang Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Sukat ng Imahe Lapad");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Sukat ng Imahe Taas");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Laki nang Imahen");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Taas");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Panatilihin Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "show Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Huwag paganahin ang Suriin");
define('MANAGE_GALLERY_DELETE_IMAGE', "Burahin Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "I-save ang uri-uriin ang pagkasunod-sunod");
define('MANAGE_GALLERY_PUBLISH_MSG', "I-click ang &#39;I-update&#39; na mag-publish <br /> iyong na-upload na mga imahe.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Lahat ng mga larawan ay nai-laki at mga setting ay nai-save.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Nagkaroon ng error sa pagbabago ng laki ng mga imahe o pag-save setting.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ang iyong imahe (s) ay nai-upload.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Nagkaroon ng error sa pag-upload ang iyong mga imahe (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Ang file na sinusubukan mong i-upload ay hindi isang imahe.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Ang file na sinusubukan mong i-upload ay masyadong malaki.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Ang pamagat ay nai-save.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Sigurado ka bang gusto mong tanggalin ang imahe");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Ang imahe ay tinanggal na.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Nagkaroon ng error sa pagbubura ng mga imahe.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Sine-save ang mga parameter at ang pagbabago ng laki ng mga imahe, mangyaring maghintay ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Ina-upload, mangyaring maghintay ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Ang sort order ay hindi pa nai-save. Gusto mo bang i-save ang sort order?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Ang imahe sort order ay nai-save.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Nagkaroon ng error sa pag-save ang imahe sort.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Ang file na sinusubukan mong i-upload ay mas malaki kaysa sa &#39;upload_max_filesize&#39; o ang mga setting na &#39;post_max_size&#39; na PHP. Makipag-ugnay sa iyong administrator ng system upang madagdagan ang mga limitasyong ito.");
?>
